@@ -2,14 +2,14 @@
 Factual Diffs API query
 """
 
-from base import Base
+from .base import Base
 
 import json
 
 class Diffs(Base):
     def __init__(self, api, path, start, end):
         self.cached_response = None
-        Base.__init__(self, api, path, {'start':int(start), 'end':int(end)})
+        Base.__init__(self, api, path, {'start':int(start), 'end':int(end)}, 'GET')
 
     def data(self):
         if not self.cached_response:
