@@ -5,7 +5,10 @@ import unittest
 
 from factual import Factual
 from factual.utils import circle, point
-from test_settings import KEY, SECRET
+from .test_settings import KEY, SECRET
+
+SANDBOX_UUID = '2aba7958-795c-4100-a221-b47df58a14ba'
+FACTUAL_UUID = '03c26917-5d66-4de9-96bc-b13066173c65'
 
 class FactualAPITestSuite(unittest.TestCase):
     def setUp(self):
@@ -57,7 +60,7 @@ class FactualAPITestSuite(unittest.TestCase):
         q = self.places.search('factual').geo(circle(34.06021, -118.41828, 1000))
         row = q.data()[0]
         self.assertEqual('Factual', row['name'])
-        self.assertEqual('1801 Avenue Of The Stars', row['address'])
+        self.assertEqual('1999 Avenue Of The Stars', row['address'])
 
     def test_read_user(self):
         q = self.places.search('sushi').user('python_driver_tester')
@@ -65,16 +68,21 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertEqual(20, included_rows)
 
     def test_resolve(self):
-        q = self.factual.resolve('places-v3', {'name': 'factual inc', 'locality': 'los angeles'})
+        q = self.factual.resolve('places-us', {"name": "factual inc", "locality": "los angeles","postcode":"90067"})
         row = q.data()[0]
         self.assertTrue(row['resolved'])
-        self.assertEqual('1801 Avenue Of The Stars', row['address'])
+        self.assertEqual('1999 Avenue Of The Stars', row['address'])
+
+    def test_resolve_debug(self):
+        q = self.factual.resolve('places-v3', {'name': 'factual inc', 'locality': 'los angeles'}, debug=True)
+        row = q.data()[0]
+        self.assertIn('similarity', row)
 
     def test_crosswalk(self):
         q = self.factual.crosswalk()
-        result = q.filters({'factual_id':'03c26917-5d66-4de9-96bc-b13066173c65','namespace':'simplegeo'}).data()
-        self.assertEqual(1, len(result))
-        self.assertEqual('SG_3ueEyOH4YN3ob9ryHjV1ey', result[0]['namespace_id'])
+        result = q.filters({'factual_id':FACTUAL_UUID,'namespace':'facebook'}).data()
+        self.assertGreaterEqual(len(result), 1)
+        self.assertEqual('151202829333', result[0]['namespace_id'])
 
     def test_schema(self):
         schema = self.places.schema()
@@ -89,9 +97,9 @@ class FactualAPITestSuite(unittest.TestCase):
             self.assertEqual(u'大阪市', r['locality'])
 
     def test_bw_encoding(self):
-        q = self.places.filters({'category': {"$bw":"Arts, Entertainment & Nightlife > Bars"}})
+        q = self.places.filters({'name': {"$bw":"Star"}})
         row = q.data()[0]
-        self.assertRegexpMatches(row['category'], "Arts, Entertainment & Nightlife > Bars")
+        self.assertRegexpMatches(row['name'], "Star")
 
     def test_in(self):
         q = self.places.filters({"locality":{"$in":["Santa Monica","Los Angeles","Culver City"]}})
@@ -126,7 +134,7 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertTrue(all(row['name'] == 'Starbucks' for row in data))
 
     def test_raw_write(self):
-        uuid = '1007462b-dd79-44f5-a69f-e0b6041fa8bd'
+        uuid = SANDBOX_UUID
         params = {'problem':'other','user':'python_driver_tester','debug':True}
         response = self.factual.raw_write('t/us-sandbox/' + uuid + '/flag', params)
         payload = json.loads(response)
@@ -168,17 +176,11 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertIn('income', income_demographics)
 
     def test_geocode(self):
-        geocode = self.factual.geocode(point(34.06021, -118.41828))
+        geocode = self.factual.geocode(point(34.058744, -118.416937))
         result = geocode.data()[0]
-        self.assertEqual('1801 Avenue Of The Stars', result['address'])
+        self.assertEqual('1999 Avenue Of The Stars', result['address'])
         self.assertLess(result['$distance'], 20)
 
-    def test_monetize(self):
-        monetize = self.factual.monetize().filters({'place_locality':'Los Angeles'})
-        result = monetize.data()
-        self.assertGreaterEqual(len(result), 1)
-        self.assertTrue(all(row['place_locality'] == 'Los Angeles' for row in result))
-
     def test_submit_without_id(self):
         values = {'longitude': 100}
         submit = self.factual.submit('us-sandbox', values=values).user('python_driver_tester')
@@ -191,7 +193,7 @@ class FactualAPITestSuite(unittest.TestCase):
 
     def test_submit_with_id(self):
         values = {'longitude': 100}
-        submit = self.factual.submit('us-sandbox', factual_id='1007462b-dd79-44f5-a69f-e0b6041fa8bd', values=values).user('python_driver_tester')
+        submit = self.factual.submit('us-sandbox', factual_id=SANDBOX_UUID, values=values).user('python_driver_tester')
         response = submit.write()
         if 'new_entity' in response:
             self.assertFalse(response['new_entity'])
@@ -200,40 +202,45 @@ class FactualAPITestSuite(unittest.TestCase):
             self.assertEqual('warning', response['status'])
 
     def test_clear(self):
-        clear = self.factual.clear('us-sandbox', '1007462b-dd79-44f5-a69f-e0b6041fa8bd', 'latitude,longitude').user('python_driver_tester')
+        clear = self.factual.clear('us-sandbox', SANDBOX_UUID, 'latitude,longitude').user('python_driver_tester')
         response = clear.write()
         self.assertIn('commit_id', response)
         self.assertGreater(len(response['commit_id']), 0)
 
     def test_flag(self):
-        flag = self.factual.flag('us-sandbox', '1007462b-dd79-44f5-a69f-e0b6041fa8bd').user('python_driver_tester').other().debug(True)
+        flag = self.factual.flag('us-sandbox', SANDBOX_UUID).user('python_driver_tester').other().debug(True)
         response = flag.write()
         self.assertEqual('ok', response['status'])
 
     def test_diffs(self):
-        diffs = self.factual.diffs('2EH4Pz', 1339123455775, 1339136968687).data()
+        diffs = self.factual.diffs('places-us', 1372694400000, 1372695300000).data()
         self.assertGreater(len(diffs), 0)
 
     def test_diffs_streaming(self):
-        diff_request = self.factual.diffs('2EH4Pz', 1339123455775, 1339136968687)
+        diff_request = self.factual.diffs('places-us', 1372694400000, 1372695300000)
         batch = diff_request.data()
         streamed = list(diff_request.stream())
-        self.assertItemsEqual(batch, streamed)
+        self.assertSequenceEqual(batch, streamed)
 
     def test_match(self):
-        match = self.factual.match('places-v3', {'name':'McDonalds','address':'10451 Santa Monica Blvd','locality':'Los Angeles','region':'CA'})
+        match = self.factual.match('places-us', {'name':'McDonalds','address':'10451 Santa Monica Blvd','locality':'Los Angeles','region':'CA'})
         match_id = match.get_id()
         self.assertEqual('c730d193-ba4d-4e98-8620-29c672f2f117', match_id)
 
     def test_multi(self):
         q1 = self.factual.table('places').filters({'postcode':'90067'})
-        q2 = self.factual.facets('places').filters({'postcode':'90067'}).select('category')
+        q2 = self.factual.facets('places').filters({'postcode':'90067'}).select('category_labels')
         response = self.factual.multi({'query1':q1,'query2':q2})
         self.assertTrue('query1' in response and 'query2' in response)
 
     def test_get_row(self):
-        row = self.factual.get_row('places', '03c26917-5d66-4de9-96bc-b13066173c65')
+        row = self.factual.get_row('places', FACTUAL_UUID)
         self.assertEqual('Factual', row['name'])
 
+    def test_boost(self):
+        boost = self.factual.boost('us-sandbox', SANDBOX_UUID).user('python_driver_tester')
+        response = boost.write()
+        self.assertEqual('ok', response['status'])
+
 if __name__ == '__main__':
     unittest.main()
